@@ -1658,7 +1658,10 @@ class TestFurl(unittest.TestCase):
     def test_equality(self):
         assert furl.furl() is not furl.furl() and furl.furl() == furl.furl()
 
+        assert furl.furl() != None
+
         url = 'https://www.yahoo.co.uk/one/two/three?a=a&b=b&m=m%26m#fragment'
+        assert furl.furl(url) != url # No furl to string comparisons (for now).
         assert furl.furl(url) == furl.furl(url)
         assert furl.furl(url).remove(path=True) != furl.furl(url)
 
